@@ -39,7 +39,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "3.2.17"
+__version__ = "3.2.18"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MAX31855.git"
 
 
@@ -78,7 +78,9 @@ class MAX31855:
             temperature = sensor.temperature
     """
 
-    def __init__(self, spi: SPI, cs: DigitalInOut) -> None:
+    def __init__(
+        self, spi: SPI, cs: DigitalInOut  # pylint: disable=invalid-name
+    ) -> None:
         self.spi_device = SPIDevice(spi, cs)
         self.data = bytearray(4)
 
